==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudbroker/resource_virtual_image/main.tf <==
/*
Пример использования
Ресурса virtual image
Ресурс позволяет:
1. Создавать образ
2. Редактировать образ
3. Удалять образ

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_virtual_image" "my_image" {
  #имя виртуального образа
  #обязательный параметр
  #тип - строка
  name = "test_vi_im_new_rename"

  #id образа, на основе котрого будет создан виртуальный
  #обязательный параметр
  #тип - число
  target_id = 6125

  #изменение связи виртуального образа
  #опциональный параметр, используется при редактировании ресурса
  #тип - число
  #link_to = 6062

  #id аккаунта владельца образа
  #опциональный параметр
  #может быть использован при редактировании образа
  #тип данных - число
  #account_id = 57252

  #имя пользователя и пароль 
  #опциаональные параметры, 
  #могут быть использованы при редактировании образа
  #тип - строка
  #username = "Valera"
  #password = "123"

  #доступность образа
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - булево значение
  #enabled = false

  #настройка доступа образа аккаунтам
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив чисел
  #пустой маасив - удаление всех доступов, если они были
  #shared_with = [28096, 57121]

  #установка computeci
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - число
  #чтобы сбросить, необходимо передать 0
  #computeci_id = 1

  #доступные стаки
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив строк
  #для удаления всех доступных стаков, необходимо передать пустой массив
  #enabled_stacks = ["9"]

  #мгновенное удаление
  #опциональный параметр, можно использовать перед удалением
  #тип - булев тип
  #permanently = true

  #причина удаления
  #опциональный параметр, можно использовать перед удалением
  #тип - строка
  #reason = "test"
}

output "test" {
  value = decort_virtual_image.my_image
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudbroker/resource_virtual_image/main.tf <==
/*
Пример использования
Ресурса virtual image
Ресурс позволяет:
1. Создавать образ
2. Редактировать образ
3. Удалять образ

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_virtual_image" "my_image" {
  #имя виртуального образа
  #обязательный параметр
  #тип - строка
  name = "test_vi_im_new_rename"

  #id образа, на основе котрого будет создан виртуальный
  #обязательный параметр
  #тип - число
  target_id = 6125

  #изменение связи виртуального образа
  #опциональный параметр, используется при редактировании ресурса
  #тип - число
  #link_to = 6062

  #id аккаунта владельца образа
  #опциональный параметр
  #может быть использован при редактировании образа
  #тип данных - число
  #account_id = 57252

  #имя пользователя и пароль 
  #опциаональные параметры, 
  #могут быть использованы при редактировании образа
  #тип - строка
  #username = "Valera"
  #password = "123"

  #доступность образа
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - булево значение
  #enabled = false

  #настройка доступа образа аккаунтам
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив чисел
  #пустой маасив - удаление всех доступов, если они были
  #shared_with = [28096, 57121]

  #установка computeci
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - число
  #чтобы сбросить, необходимо передать 0
  #computeci_id = 1

  #доступные стаки
  #опциональный параметр, используется на уже созданном ресурсе
  #тип - массив строк
  #для удаления всех доступных стаков, необходимо передать пустой массив
  #enabled_stacks = ["9"]

  #мгновенное удаление
  #опциональный параметр, можно использовать перед удалением
  #тип - булев тип
  #permanently = true

  #причина удаления
  #опциональный параметр, можно использовать перед удалением
  #тип - строка
  #reason = "test"
}

output "test" {
  value = decort_virtual_image.my_image
}
